@@ -3,7 +3,7 @@
 #' @keywords internal
 #'
 #' @param .data A tidyseurat
-to_tib = function(.data){ .data[[]] %>% as_tibble(rownames = "cell") }
+to_tib = function(.data){ .data[[]] %>% as_tibble(rownames = c_(.data)$name) }
 
 # Greater than
 gt = function(a, b){	a > b }
@@ -132,10 +132,10 @@ get_abundance_sc_wide = function(.data, features = NULL, all = FALSE, assay = .d
     GetAssayData(slot=slot) %>%
     as.matrix() %>%
     t %>%
-    as_tibble(rownames = "cell") %>% 
+    as_tibble(rownames = c_(.data)$name) %>% 
     
     # Add prefix
-    setNames(c("cell", sprintf("%s%s", prefix, colnames(.)[-1]))) 
+    setNames(c(c_(.data)$name, sprintf("%s%s", prefix, colnames(.)[-1]))) 
     
 
 }
@@ -209,11 +209,11 @@ get_abundance_sc_long = function(.data, features = NULL, all = FALSE, exclude_ze
            when(exclude_zeros ~ (.) %>% { x = (.); x[x == 0] <- NA; x }, ~ (.)) %>%
 
            data.frame(check.names = FALSE) %>%
-           as_tibble(rownames = "feature") %>%
+           as_tibble(rownames = ".feature") %>%
            tidyr::pivot_longer(
-             cols = -feature,
-             names_to ="cell",
-             values_to = "abundance" %>% paste(.y, sep="_"),
+             cols = - .feature,
+             names_to =c_(.data)$name,
+             values_to = ".abundance" %>% paste(.y, sep="_"),
              values_drop_na  = TRUE
            )
          #%>%
@@ -221,7 +221,7 @@ get_abundance_sc_long = function(.data, features = NULL, all = FALSE, exclude_ze
 
 
     ) %>%
-    Reduce(function(...) full_join(..., by=c("feature", "cell")), .)
+    Reduce(function(...) full_join(..., by=c(".feature", c_(.data)$name)), .)
 
 }
 
@@ -243,7 +243,7 @@ as_meta_data = function(.data, seurat_object){
   .data %>%
     select_if(!colnames(.) %in% col_to_exclude) %>%
     #select(-one_of(col_to_exclude)) %>%
-    column_to_rownames("cell")
+    column_to_rownames(c_(seurat_object)$name)
 }
 
 #' @importFrom purrr map_chr
@@ -265,9 +265,8 @@ get_special_datasets = function(seurat_object, n_dimensions_to_return = Inf){
 
 }
 
-get_needed_columns = function(){
-  #c("cell",  "orig.ident", "nCount_RNA", "nFeature_RNA")
-  c("cell")
+get_needed_columns = function(.data){
+  c(c_(.data)$name)
 }
 
 #' Convert array of quosure (e.g. c(col_a, col_b)) into character vector
@@ -329,3 +328,52 @@ clean_seurat_object = function(.data){
   .data
   
 }
+
+
+# This function is used for the change of special sample column to .sample
+# Check if "sample" is included in the query and is not part of any other existing annotation
+#' @importFrom stringr str_detect
+#' @importFrom stringr regex
+is_sample_feature_deprecated_used = function(.data, user_columns, use_old_special_names = FALSE){
+  
+  old_standard_is_used_for_cell = 
+    (
+      ( any(str_detect(user_columns  , regex("\\bcell\\b"))) & !any(str_detect(user_columns  , regex("\\W*(\\.cell)\\W*")))  ) |
+        "cell" %in% user_columns 
+    ) & 
+    !"cell" %in% colnames(.data@meta.data)
+  
+  old_standard_is_used = old_standard_is_used_for_cell
+  
+  if(old_standard_is_used){
+    warning("tidyseurat says: from version 1.3.1, the special columns including cell id (colnames(se)) has changed to \".cell\". This dataset is returned with the old-style vocabulary (cell), however we suggest to update your workflow to reflect the new vocabulary (.cell)")
+    
+    use_old_special_names = TRUE
+  }
+  
+  use_old_special_names
+}
+
+get_special_column_name_symbol = function(name){
+  list(name = name, symbol = as.symbol(name))
+}
+
+# Key column names
+ping_old_special_column_into_metadata = function(.data){
+  
+  .data@misc$cell__ = get_special_column_name_symbol("cell")
+
+  .data
+}
+
+get_special_column_name_cell = function(name){
+  list(name = name, symbol = as.symbol(name))
+}
+
+cell__ = get_special_column_name_symbol(".cell")
+
+c_ =  function(x){
+  # Check if old deprecated columns are used
+  if("cell__" %in% names(x@misc)) cell__ = x@misc$cell__
+  return(cell__)
+}
